Pilar module for *pyobs*
========================


Install *pyobs-pilar*
-------------------
Clone the repository:

    git clone https://github.com/pyobs/pyobs-pilar.git


Install dependencies:

    cd pyobs-pilar
    pip3 install -r requirements
        
And install it:

    python3 setup.py install


Dependencies
------------
* **pyobs** for the core funcionality. It is not included in the *requirements.txt*, so needs to be installed 
  separately.
